# mu2.validate

An easy use Validate.

[![mu2.validate](https://img.shields.io/npm/v/mu2.validate.svg?style=flat-square)](https://www.npmjs.com/package/mu2.validate)

### 安装

``` bash
$ npm install mu2.validate
```

### 使用

``` javascript
import validate from 'mu2.validate'

let obj = {
  email: 'mu2atgamil.com',
  password: '12334',
  repeat: '123345677',
  inviter: '123'
}

let condition = {
  email: {
    rules: 'required|isEmail',
    errors: '邮箱不能为空|邮箱入正确的密码'
  },
  password: {
    rules: 'required|minLength(6)|isAlphanumeric',
    errors: '密码不能为空|密码长度最少6位|密码必须包含数字和字母'
  },
  repeat: {
    rules: 'required|same(password)',
    errors: '不能为空|必须和密码相同'
  },
  inviter: { // 没有 required 为非必须属性
    rules: 'isPhone',
    errors: '请输入正确的手机号'
  }
}

let errors = validate(obj, condition)

// errors
[
  {
    "path": "email.isEmail",
    "error": "邮箱入正确的密码"
  },
  {
    "path": "password.minLength(6)",
    "error": "密码长度最少6位"
  },
  {
    "path": "repeat.same(password)",
    "error": "必须和密码相同"
  },
  {
    "path": "inviter.isPhone",
    "error": "请输入正确的手机号"
  }
]
```

### 规则

* errors - 错误信息需要用 `|` 隔开
* rules  - 判断规则需要用 `|` 隔开

> * required - 必须不能为空
> * isArray - 是否为数组
> * isNumber(len) - 是否为整数(整数字符)，len - 长度（可选）
> * isNumeric(len) - 是否为数字(浮点数)，len - 长度（可选）
> * isAlpha(len) - 是否为英文字母，len - 长度（可选）
> * isAlphanumeric(len) - 是否为英文字母和数字，len - 长度（可选）
> * isEmail - 是否为邮箱
> * isPhone - 是否为手机号
> * isChinese - 是否为中文
> * isEqual(str) - 是否等于某个值
> * isNotEqual(str) - 是否不等于某个值
> * isIn([]) - 是否包含在某个数组内
> * isNotIn([]) - 是否不包含在某个数组内
> * maxLength(16) - 最大长度
> * minLength(6) - 最小长度
> * maxValue(99) - 最大值
> * minValue(10) - 最小值
> * same(path) - 和其他某个属性值相同
> * notSame(path) - 和其他某个属性值不相同

### 自定义规则

```javascript
{
  path: {
    rules: 'matchPhone|matchEmail|matchNumber',
    matchPhone: /\phone/,
    matchEmail: /\email/,
    matchNumber: /\number/,
    errors: 'not match phone|not match email|not match number'
  }
}
```

### MIT license

Copyright (c) 2017 mufeng <mufeng.me@gmail.com>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the &quot;Software&quot;), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.